==> Chart-Plotly-0.041.tar.gz: Chart-Plotly-0.041/lib/Chart/Plotly/Trace/Streamtube/Colorbar/Title/Font.pm <==
package Chart::Plotly::Trace::Streamtube::Colorbar::Title::Font;
use Moose;
use MooseX::ExtraArgs;
use Moose::Util::TypeConstraints qw(enum union);
if ( !defined Moose::Util::TypeConstraints::find_type_constraint('PDL') ) {
    Moose::Util::TypeConstraints::type('PDL');
}

our $VERSION = '0.041';    # VERSION

# ABSTRACT: This attribute is one of the possible options for the trace streamtube.

sub TO_JSON {
    my $self       = shift;
    my $extra_args = $self->extra_args // {};
    my $meta       = $self->meta;
    my %hash       = %$self;
    for my $name ( sort keys %hash ) {
        my $attr = $meta->get_attribute($name);
        if ( defined $attr ) {
            my $value = $hash{$name};
            my $type  = $attr->type_constraint;
            if ( $type && $type->equals('Bool') ) {
                $hash{$name} = $value ? \1 : \0;
            }
        }
    }
    %hash = ( %hash, %$extra_args );
    delete $hash{'extra_args'};
    if ( $self->can('type') && ( !defined $hash{'type'} ) ) {
        $hash{type} = $self->type();
    }
    return \%hash;
}

has color => ( is  => "rw",
               isa => "Str", );

has description => (
    is => "ro",
    default =>
      "Sets this color bar's title font. Note that the title's font used to be set by the now deprecated `titlefont` attribute.",
);

has family => (
    is  => "rw",
    isa => "Str",
    documentation =>
      "HTML font family - the typeface that will be applied by the web browser. The web browser will only be able to apply a font if it is available on the system which it operates. Provide multiple font families, separated by commas, to indicate the preference in which to apply fonts if they aren't available on the system. The plotly service (at https://plot.ly or on-premise) generates images on a server, where only a select number of fonts are installed and supported. These include *Arial*, *Balto*, *Courier New*, *Droid Sans*,, *Droid Serif*, *Droid Sans Mono*, *Gravitas One*, *Old Standard TT*, *Open Sans*, *Overpass*, *PT Sans Narrow*, *Raleway*, *Times New Roman*.",
);

has size => ( is  => "rw",
              isa => "Num", );

__PACKAGE__->meta->make_immutable();
1;

__END__

=pod

=encoding utf-8

=head1 NAME

Chart::Plotly::Trace::Streamtube::Colorbar::Title::Font - This attribute is one of the possible options for the trace streamtube.

=head1 VERSION

version 0.041

=head1 SYNOPSIS

 use Chart::Plotly;
 use Chart::Plotly::Trace::Streamtube;
 use Chart::Plotly::Plot;
 
 # Example from https://github.com/plotly/plotly.js/blob/273292dcb24170f775dbc7ebb285c9b6a80b10f4/test/image/mocks/gl3d_streamtube-simple.json
 
 my $trace = Chart::Plotly::Trace::Streamtube->new(
     cmax    => 3,
     cmin    => 0,
     sizeref => 0.5,
     type    => 'streamtube',
     u       => [ (1) x 9, (1.8414709848079) x 9, (1.90929742682568) x 9 ],
     v       => [
            (1) x 3,
            (0.54030230586814) x 3,
            (-0.416146836547142) x 3,
            (1) x 3,
            (0.54030230586814) x 3,
            (-0.416146836547142) x 3,
            (1) x 3,
            (0.54030230586814) x 3,
            (-0.416146836547142) x 3
     ],
     w => [ 0,                  0.0886560619984019, 0.169392742018511,  0,
            0.0886560619984019, 0.169392742018511,  0,                  0.0886560619984019,
            0.169392742018511,  0,                  0.0886560619984019, 0.169392742018511,
            0,                  0.0886560619984019, 0.169392742018511,  0,
            0.0886560619984019, 0.169392742018511,  0,                  0.0886560619984019,
            0.169392742018511,  0,                  0.0886560619984019, 0.169392742018511,
            0,                  0.0886560619984019, 0.169392742018511
     ],
     x => [ (0) x 9, (1) x 9, (2) x 9 ],
     y => [ (0) x 3, (1) x 3, (2) x 3, (0) x 3, (1) x 3, (2) x 3, (0) x 3, (1) x 3, (2) x 3 ],
     z => [ 0, 1, 2, 0, 1, 2, 0, 1, 2, 0, 1, 2, 0, 1, 2, 0, 1, 2, 0, 1, 2, 0, 1, 2, 0, 1, 2 ]
 
 );
 
 my $plot = Chart::Plotly::Plot->new( traces => [$trace],
                                      layout => {
                                                  scene => {
                                                             camera => {
                                                                         eye => { x => -0.724361245886518,
                                                                                  y => 1.9269804254718,
                                                                                  z => 0.670482829986172
                                                                         }
                                                             }
                                                  }
                                      }
 );
 
 Chart::Plotly::show_plot($plot);

=head1 DESCRIPTION

This attribute is part of the possible options for the trace streamtube.

This file has been autogenerated from the official plotly.js source.

If you like Plotly, please support them: L<https://plot.ly/> 
Open source announcement: L<https://plot.ly/javascript/open-source-announcement/>

Full reference: L<https://plot.ly/javascript/reference/#streamtube>

=head1 DISCLAIMER

This is an unofficial Plotly Perl module. Currently I'm not affiliated in any way with Plotly. 
But I think plotly.js is a great library and I want to use it with perl.

=head1 METHODS

=head2 TO_JSON

Serialize the trace to JSON. This method should be called only by L<JSON> serializer.

=head1 ATTRIBUTES

=over

=item * color

=item * description

=item * family

HTML font family - the typeface that will be applied by the web browser. The web browser will only be able to apply a font if it is available on the system which it operates. Provide multiple font families, separated by commas, to indicate the preference in which to apply fonts if they aren't available on the system. The plotly service (at https://plot.ly or on-premise) generates images on a server, where only a select number of fonts are installed and supported. These include *Arial*, *Balto*, *Courier New*, *Droid Sans*,, *Droid Serif*, *Droid Sans Mono*, *Gravitas One*, *Old Standard TT*, *Open Sans*, *Overpass*, *PT Sans Narrow*, *Raleway*, *Times New Roman*.

=item * size

=back

=head1 AUTHOR

Pablo Rodríguez González <pablo.rodriguez.gonzalez@gmail.com>

=head1 COPYRIGHT AND LICENSE

This software is Copyright (c) 2020 by Pablo Rodríguez González.

This is free software, licensed under:

  The MIT (X11) License

=cut

==> Chart-Plotly-0.042.tar.gz: Chart-Plotly-0.042/lib/Chart/Plotly/Trace/Streamtube/Colorbar/Title/Font.pm <==
package Chart::Plotly::Trace::Streamtube::Colorbar::Title::Font;
use Moose;
use MooseX::ExtraArgs;
use Moose::Util::TypeConstraints qw(enum union);
if ( !defined Moose::Util::TypeConstraints::find_type_constraint('PDL') ) {
    Moose::Util::TypeConstraints::type('PDL');
}

our $VERSION = '0.042';    # VERSION

# ABSTRACT: This attribute is one of the possible options for the trace streamtube.

sub TO_JSON {
    my $self       = shift;
    my $extra_args = $self->extra_args // {};
    my $meta       = $self->meta;
    my %hash       = %$self;
    for my $name ( sort keys %hash ) {
        my $attr = $meta->get_attribute($name);
        if ( defined $attr ) {
            my $value = $hash{$name};
            my $type  = $attr->type_constraint;
            if ( $type && $type->equals('Bool') ) {
                $hash{$name} = $value ? \1 : \0;
            }
        }
    }
    %hash = ( %hash, %$extra_args );
    delete $hash{'extra_args'};
    if ( $self->can('type') && ( !defined $hash{'type'} ) ) {
        $hash{type} = $self->type();
    }
    return \%hash;
}

has color => ( is  => "rw",
               isa => "Str", );

has description => (
    is      => "ro",
    default =>
      "Sets this color bar's title font. Note that the title's font used to be set by the now deprecated `titlefont` attribute.",
);

has family => (
    is            => "rw",
    isa           => "Str",
    documentation =>
      "HTML font family - the typeface that will be applied by the web browser. The web browser will only be able to apply a font if it is available on the system which it operates. Provide multiple font families, separated by commas, to indicate the preference in which to apply fonts if they aren't available on the system. The Chart Studio Cloud (at https://chart-studio.plotly.com or on-premise) generates images on a server, where only a select number of fonts are installed and supported. These include *Arial*, *Balto*, *Courier New*, *Droid Sans*,, *Droid Serif*, *Droid Sans Mono*, *Gravitas One*, *Old Standard TT*, *Open Sans*, *Overpass*, *PT Sans Narrow*, *Raleway*, *Times New Roman*.",
);

has size => ( is  => "rw",
              isa => "Num", );

__PACKAGE__->meta->make_immutable();
1;

__END__

=pod

=encoding utf-8

=head1 NAME

Chart::Plotly::Trace::Streamtube::Colorbar::Title::Font - This attribute is one of the possible options for the trace streamtube.

=head1 VERSION

version 0.042

=head1 SYNOPSIS

 use Chart::Plotly;
 use Chart::Plotly::Trace::Streamtube;
 use Chart::Plotly::Plot;
 
 # Example from https://github.com/plotly/plotly.js/blob/273292dcb24170f775dbc7ebb285c9b6a80b10f4/test/image/mocks/gl3d_streamtube-simple.json
 
 my $trace = Chart::Plotly::Trace::Streamtube->new(
     cmax    => 3,
     cmin    => 0,
     sizeref => 0.5,
     type    => 'streamtube',
     u       => [ (1) x 9, (1.8414709848079) x 9, (1.90929742682568) x 9 ],
     v       => [
            (1) x 3,
            (0.54030230586814) x 3,
            (-0.416146836547142) x 3,
            (1) x 3,
            (0.54030230586814) x 3,
            (-0.416146836547142) x 3,
            (1) x 3,
            (0.54030230586814) x 3,
            (-0.416146836547142) x 3
     ],
     w => [ 0,                  0.0886560619984019, 0.169392742018511,  0,
            0.0886560619984019, 0.169392742018511,  0,                  0.0886560619984019,
            0.169392742018511,  0,                  0.0886560619984019, 0.169392742018511,
            0,                  0.0886560619984019, 0.169392742018511,  0,
            0.0886560619984019, 0.169392742018511,  0,                  0.0886560619984019,
            0.169392742018511,  0,                  0.0886560619984019, 0.169392742018511,
            0,                  0.0886560619984019, 0.169392742018511
     ],
     x => [ (0) x 9, (1) x 9, (2) x 9 ],
     y => [ (0) x 3, (1) x 3, (2) x 3, (0) x 3, (1) x 3, (2) x 3, (0) x 3, (1) x 3, (2) x 3 ],
     z => [ 0, 1, 2, 0, 1, 2, 0, 1, 2, 0, 1, 2, 0, 1, 2, 0, 1, 2, 0, 1, 2, 0, 1, 2, 0, 1, 2 ]
 
 );
 
 my $plot = Chart::Plotly::Plot->new( traces => [$trace],
                                      layout => {
                                                  scene => {
                                                             camera => {
                                                                         eye => { x => -0.724361245886518,
                                                                                  y => 1.9269804254718,
                                                                                  z => 0.670482829986172
                                                                         }
                                                             }
                                                  }
                                      }
 );
 
 Chart::Plotly::show_plot($plot);

=head1 DESCRIPTION

This attribute is part of the possible options for the trace streamtube.

This file has been autogenerated from the official plotly.js source.

If you like Plotly, please support them: L<https://plot.ly/> 
Open source announcement: L<https://plot.ly/javascript/open-source-announcement/>

Full reference: L<https://plot.ly/javascript/reference/#streamtube>

=head1 DISCLAIMER

This is an unofficial Plotly Perl module. Currently I'm not affiliated in any way with Plotly. 
But I think plotly.js is a great library and I want to use it with perl.

=head1 METHODS

=head2 TO_JSON

Serialize the trace to JSON. This method should be called only by L<JSON> serializer.

=head1 ATTRIBUTES

=over

=item * color

=item * description

=item * family

HTML font family - the typeface that will be applied by the web browser. The web browser will only be able to apply a font if it is available on the system which it operates. Provide multiple font families, separated by commas, to indicate the preference in which to apply fonts if they aren't available on the system. The Chart Studio Cloud (at https://chart-studio.plotly.com or on-premise) generates images on a server, where only a select number of fonts are installed and supported. These include *Arial*, *Balto*, *Courier New*, *Droid Sans*,, *Droid Serif*, *Droid Sans Mono*, *Gravitas One*, *Old Standard TT*, *Open Sans*, *Overpass*, *PT Sans Narrow*, *Raleway*, *Times New Roman*.

=item * size

=back

=head1 AUTHOR

Pablo Rodríguez González <pablo.rodriguez.gonzalez@gmail.com>

=head1 COPYRIGHT AND LICENSE

This software is Copyright (c) 2022 by Pablo Rodríguez González.

This is free software, licensed under:

  The MIT (X11) License

=cut
